/*
 *  RASYS.H
 *
 *    Definitions of some of the system files for RemoteAccess in C
 *
 *    All "strings" below are in TP format, since RA is written in that
 *    language
 *
 *    The contents of this file was correct for RA 0.03, and has not been
 *    updated with the latest additions.
 *
 *    Revision history:
 *      Jul 10, 1991/Mats Wallin - First version
 *      Sep  6, 1992/Mats Wallin - Modified to not require my usual header files
 */


#ifndef __RASYS_INC__
#define __RASYS_INC__


/* ---------------------------------------------------------------------- *
 *
 *  Define new datatypes
 *
 * ---------------------------------------------------------------------- */


typedef unsigned char   byte;
typedef unsigned short  word;
typedef unsigned long   dword;


/* PSTR is used when defining a pascal string. The result will be         */
/* a byte-declared variable containing the length, and a char array       */
/* containing the string itself. Ex:                                      */
/* PSTR( str, 5 );    = byte lstr; char str [5];                          */

#define PSTR(str,len) byte l##str; char str [len]


/* ---------------------------------------------------------------------- *
 *
 *  Standard constants
 *
 * ---------------------------------------------------------------------- */

#define TRUE    1
#define FALSE   0


/* ----------------------------------------------------------------------- *
 *
 *  FlagType, used by RA for security checks
 *
 * ----------------------------------------------------------------------- */

typedef struct
{
  byte      a;
  byte      b;
  byte      c;
  byte      d;
} _FLAGTYPE, * _FLAGTYPEPTR;


/* ----------------------------------------------------------------------- *
 *
 *  CONFIG.RA
 *
 * ----------------------------------------------------------------------- */

typedef struct
{
  word    VersionID;            /* Ver no of this file, should be RA_THISREV */
  byte    CommPort;             /* COMx: port number, COM1 = 1 */
  long    Baud;                 /* Bps rate to use with modem */
  byte    InitTries;            /* Number of times to try to initialize modem */
  PSTR(   InitStr, 70 );        /* Initialisation string */
  PSTR(   BusyStr, 70 );        /* Modem string to take modem off-hook */
  PSTR(   InitResp, 40 );       /* Initialisation response */
  PSTR(   BusyResp, 40 );       /* Response to BusyStr */
  PSTR(   Connect300, 40 );     /* 300bps connections response */
  PSTR(   Connect1200, 40 );    /* 1200bps */
  PSTR(   Connect2400, 40 );    /* 2400bps */
  PSTR(   Connect4800, 40 );    /* 4800bps */
  PSTR(   Connect9600, 40 );    /* 9600bps */
  PSTR(   Connect19k, 40 );     /* 19.2kbps */
  PSTR(   Connect38k, 40 );     /* 38kbps */
  byte    AnswerPhone;          /* If RA should answer phone manually */
  PSTR(   Ring, 20 );           /* Modem "RING" code */
  PSTR(   AnswerStr, 20 );      /* "ATA"-style modem command to answer phone */
  byte    FlushBuffer;          /* [not-used] */
  int     ModemDelay;           /* Delay to pause between lines sent to modem */
  int     MinimumBaud;          /* Minimum bps to allow a connection */
  int     GraphicsBaud;         /* Minimum bps to allow ANSI graphics capabilities */
  int     TransferBaud;         /* Minimum bps to allow file-transfer */
  PSTR(   SlowBaudTimeStart, 5);/* Time to start 300bps file-transfer window */
  PSTR(   SlowBaudTimeEnd, 5 ); /* Time to stop 300bps file-transfer window */
  PSTR(   DownloadTimeStart, 5);/* Time to start file-transfer window */
  PSTR(   DownloadTimeEnd, 5 ); /* Time to stop file-transfer window */
  PSTR(   PagingTimeStart, 5 ); /* Time to start Sysop-paging window */
  PSTR(   PagingTimeEnd, 5 );   /* Time to stop Sysop-paging window */
  PSTR(   LoadingMsg, 70 );     /* Message to display while loading external program */
  PSTR(   ListPrompt, 70 );     /* Prompt for 'list' menu-type */
  word    PwdExpiry;            /* Number of calls to force password-change */
  PSTR(   MenuPath, 60 );       /* Path to *.MNU files */
  PSTR(   TextPath, 60 );       /* Path to *.ASC and *.ANS files */
  PSTR(   AttachPath, 60 );     /* Path to file attaches (local?) */
  PSTR(   NodelistPath, 60 );   /* Path to nodelist data-files */
  PSTR(   MsgBasePath, 60 );    /* Path to MSG*.BBS, USERS.BBS, LASTREAD.BBS and COMBINED.BBS files */
  PSTR(   SysPath, 60 );        /* Path to main RA 'root' system directory */
  PSTR(   ExternalEdCmd, 60 );  /* Command to execute external message-editor */
  struct
  {
    word zone;
    word net;
    word node;
    word point;
  }       Address [10];         /* Primary and AKA address info */
  PSTR(   SystemName, 30 );     /* Name of system */
  word    NewSecurity;          /* New-user security */
  word    NewCredit;            /* New-user netmail credit */
  _FLAGTYPE NewFlags;           /* New-user flags */
  PSTR(     OriginLine, 60 );   /* Default ' * Origin:'-line */
  PSTR(     QuoteString, 15 );  /* String to precede message quotes */
  PSTR(     Sysop, 35 );        /* Name of System Operator */
  PSTR(     LogFileName, 60 );  /* Filename of log-file */
  byte      FastLogon;          /* Should names be prompted in local mode */
  byte      AllowSysRem;        /* Should the Sysop be allowed to log-on remotely */
  byte      MonoMode;           /* Should RA use B&W colours */
  byte      StrictPwdChecking;  /* Sets if RA should strictly compare new and old psw */
  byte      DirectWrite;        /* Sets if RA should write directly to the screen */
  byte      SnowCheck;          /* Sets if RA should worry about possible snow */
  int       CreditFactor;       /* Upload credit factor */
  word      UserTimeOut;        /* Number of seconds to decide a User inactivity */
  word      LogonTime;          /* Number of minuts allowed to get to the TOP menu */
  word      PasswordTries;      /* Number of tries a user can have at providing a correct psw */
  word      MaxPage;            /* Max no of Sysop-pages allowed per call */
  word      PageLength;         /* Sysop-page length (in seconds) */
  byte      CheckForMultiLogon; /* Specifies if RA should check user isn't online on two lines */
  byte      ExcludeSysopFromList;/*Tells RA if the Sysop should be placed on user-lists */
  byte      OneWordNames;       /* If users are allowed to logon with one-word names */
  byte      CheckMail;          /* Specifies if mail-checking should be done */
  byte      AskVoicePhone;      /* Should new users be asked for voice number */
  byte      AskDataPhone;       /* Should new users be asked for data number */
  byte      DoFullMailCheck;    /* If RA only should check messages after the latest read */
  byte      AllowFileShells;    /* If shell control codes is allowed in text-files */
  byte      FixUploadDates;     /* Specifies if file-dates should be reset to when they were received */
  byte      ShowFileDates;      /* If filedates should be displayed in filelistings */
  byte      ANSI;               /* Controls new-user setting of ANSI graphics */
  byte      ClearScreen;        /* Controls new-user setting of screen-clearing */
  byte      MorePrompt;         /* Controls new-user setting of Continue[Y/n/=] */
  byte      UploadMsgs;         /* [not-used] */
  byte      KillSent;           /* Controls use of 'Kill/Sent' on netmail */
  word      CrashAskSec;        /* Min security to have option for crash */
  _FLAGTYPE CrashAskFlags;      /* Flags required to have option for crash */
  word      CrashSec;           /* Min security to force use of crash */
  _FLAGTYPE CrashFlags;         /* Flags required to force use of crash */
  word      FAttachSec;         /* Sec needed to have option for fileattach */
  _FLAGTYPE FAttachFlags;       /* Flags needed to have opt for fileattach */

/* NOTE: The following attribute fields are for local control ONLY */

  byte      NormFore;           /* Foreground for normal text */
  byte      NormBack;           /* Background for normal text */
  byte      StatFore;           /* Foreground for status-line */
  byte      StatBack;           /* Background for status-line */
  byte      HiBack;             /* Background for highlight text */
  byte      HiFore;             /* Foreground for highlight text */
  byte      WindFore;           /* Foreground for window text */
  byte      WindBack;           /* Background for window text */

/* NOTE: The following values specify errorlevel numbers given off the  */
/*       front-end-mailer for each bps rate                             */

  byte      ExitLocal;
  byte      Exit300;
  byte      Exit1200;
  byte      Exit2400;
  byte      Exit4800;
  byte      Exit9600;
  byte      Exit19k;
  byte      Exit38k;

  byte      MultiLine;          /* Tells RA if it is running on a multiline system */
  byte      MinPwdLen;          /* Minimum password-length (characters) */
  word      MinUpSpace;         /* Min disk space required for upload */
  byte      HotKeys;            /* Controls new-user setting of use of hotkeys */
  byte      BorderFore;         /* Foreground of window-border */
  byte      BorderBack;         /* Background of window-border */
  byte      BarFore;            /* Foreground of menu-bar */
  byte      BarBack;            /* Background of menu-bar */
  byte      LogStyle;           /* See below */
  byte      MultiTasker;        /* See below */
  byte      PwdBoard;           /* Msg area # to use for psw failure msg */
  word      BufferSize;         /* Internal buffer-size to use */
  struct
  {
    byte l;
    char s [60];
  }         FKeys [10];         /* Function-key command-lines */
  byte      WhyPage;            /* Ask why user wanted to chat */
  byte      LeaveMsg;           /* Msg area # to use for reason to chat */
  byte      ShowMissingFiles;   /* If missing files should be displayed */
  PSTR(     MissingString, 10 );/* Text to display when file is missing */
  byte      AllowNetmailReplies;/* If netmail replies are allowed */
  PSTR(     LogonPrompt, 40 );  /* Text for the 'Username:' prompt */
  byte      CheckNewFiles;      /* Specifies if new files should be searched for */
  PSTR(     ReplyHeader, 60 );  /* Line to add at the top of a reply */
  byte      BlankSecs;          /* # of seconds before blanking screen */
  byte      ProtocolAttrib [6]; /* Flags for the internal protocols */
  PSTR(     ErrorFreeString,15);/* Modem text when the connection is error free */
  byte      DefaultCombined[25];/* Default combined setting */
  word      RenumThreshold;     /* ??? */
  byte      KillMissingEntries; /* Delete entries without a matching file */
  byte      Orphans;            /* What to do with files without an entry */
  byte      AskForHandle;       /* Ask new user for a handle */
  byte      AskForBirthDate;    /* Ask new user for their birth date */
  word      SubSec;             /* Users security when subscription expired */
  byte      ConfirmMsgDeletes;  /* Should message deletion be confirmed */
  PSTR(     LocationPrompt, 60);/* Prompt when asking for users location */
  PSTR(     PagePrompt, 60 );   /* Prompt when asking why user want to chat */
  char      FutureExpansion [727];
} _RACONFIG, * _RACONFIGPTR, far * _RACONFIGFPTR;

/* Versionsnummer fr denna fil */

#define RA_THISREV      0x0003

/* ASKTYPE, anvnds i ett antal flt */

#define RA_ASKTYPE_YES  0x00
#define RA_ASKTYPE_NO   0x01
#define RA_ASKTYPE_ASK  0x02

/* RACONFIG.LogStyle */

#define RA_CFG_OPUSLOG    0x00
#define RA_CFG_FDLOG      0x01

/* RACONFIG.MultiTasker */

#define RA_CFG_NONE       0x00
#define RA_CFG_ATBIOS     0x01
#define RA_CFG_DOUBLEDOS  0x02
#define RA_CFG_DESQVIEW   0x03
#define RA_CFG_TOPVIEW    0x04
#define RA_CFG_MULTILINK  0x05
#define RA_CFG_PCMOS386   0x06

/* RACONFIG.Orphans */

#define RA_CFG_IGNORE     0x00
#define RA_CFG_CREATE     0x01
#define RA_CFG_ECHOMAIL   0x02


/* ----------------------------------------------------------------------- *
 *
 *  MESSAGES.RA
 *
 * ----------------------------------------------------------------------- */

typedef struct
{
  PSTR(     Name, 40 );  
  byte      Typ;
  byte      MsgKinds;
  byte      Attribute;
  byte      DaysKill;           /* Kill older than 'x' days */
  byte      RecvKill;           /* Kill recv msgs, recv for more than 'x' days */
  word      CountKill;
  word      ReadSecurity;
  _FLAGTYPE ReadFlags;
  word      WriteSecurity;
  _FLAGTYPE WriteFlags;
  word      SysopSecurity;
  _FLAGTYPE SysopFlags;
  PSTR(     OriginLine, 60 );
  byte      AkaAddress;
} _RAMESSAGES, * _RAMESSEGESPTR, far * _RAMESSAGESFPTR;


/* _RAMESSAGES.Typ */

#define RA_MSG_LOCAL      0x00        /* Local area */
#define RA_MSG_NETMAIL    0x01        /* Netmail area */
#define RA_MSG_ECHOMAIL   0x02        /* Echomail area */

/* _RAMESSAGES.MsgKinds */

#define RA_MSG_BOTH       0x00        /* Bde publika och privata brev */
#define RA_MSG_PRIVATE    0x01        /* Endast pvt brev */
#define RA_MSG_PUBLIC     0x02        /* Endast publika brev */
#define RA_MSG_RDONLY     0x03        /* Endast lsning */

/* _RAMESSAGES.Attribute */

#define RA_MSG_ECHOINFO   0x01        /* Append echomail info */
#define RA_MSG_COMBINED   0x02        /* Allow combined access */
#define RA_MSG_FATTACH    0x04        /* Allow file attaches */
#define RA_MSG_ALIASES    0x08        /* Allow aliases */
#define RA_MSG_HANDL_ONLY 0x20        /* Force handle */


/* ----------------------------------------------------------------------- *
 *
 *  LASTCALL.BBS
 *
 * ----------------------------------------------------------------------- */

typedef struct
{
  byte      line;
  PSTR(     name, 35 );
  PSTR(     handle, 35 );
  PSTR(     city, 25 );
  word      baud;
  long      times;
  PSTR(     logon, 5 );
  PSTR(     logoff, 5 );
  byte      attribute;
} _RALASTCALL, * _RALASTCALLPTR, far * _RALASTCALLFPTR;


/* ----------------------------------------------------------------------- *
 *
 *  MSGIDX.BBS
 *
 * ----------------------------------------------------------------------- */

typedef struct
{
  word      msgnum;
  byte      board;
} _QIDX, * _QIDXPTR;


/* ----------------------------------------------------------------------- *
 *
 *  MSGHDR.BBS
 *
 * ----------------------------------------------------------------------- */

typedef struct 
{
  word      msgnum;
  word      replyto;
  word      seealso;
  word      times_read;
  word      startrec;
  int       numrecs;
  word      destnet;
  word      destnode;
  word      orignet;
  word      orignode;
  byte      destzone;
  byte      origzone;
  word      cost;
  byte      msgattr;
  byte      netattr;
  byte      board;
  PSTR(     posttime, 5 );
  PSTR(     postdate, 8 );
  PSTR(     whoto, 35 );
  PSTR(     whofrom, 35 );
  PSTR(     subj, 72 );
} _QHDR, * _QHDRPTR;


/* Message attributes (_QHDR.msgattr) */

#define QHDR_DELETED    0x01        /* Meddelandet r raderat             */
#define QHDR_UNMOV_NETM 0x02        /* Ej exporterat netmail meddelande   */
#define QHDR_NETMAIL    0x04        /* Netmail meddelande                 */
#define QHDR_PVT        0x08        /* Privat meddelande                  */
#define QHDR_RCVD       0x10        /* Brevet lst av mottagaren          */
#define QHDR_UNMOV_ECHO 0x20        /* Ej exporterat echo meddelande      */
#define QHDR_LOCAL      0x40        /* Brevet r skrivet hr              */

/* Net attributes (_QHDR.netattr) */

#define QHDR_KILL       0x01        /* Radera brevet nr det r snt      */
#define QHDR_SENT       0x02        /* Brevet r snt                     */
#define QHDR_FILE       0x04        /* File attach, fil fljer med brevet */
#define QHDR_CRASH      0x08        /* Hg prioritet                      */
#define QHDR_RR_REQ     0x10        /* Begr kvittens p mottagning       */
#define QHDR_AUDIT_REQ  0x20        /* Audit request (???)                */
#define QHDR_IS_RR      0x40        /* r en kvittens                     */


/* ----------------------------------------------------------------------- *
 *
 *  MSGTXT.BBS
 *
 * ----------------------------------------------------------------------- */

typedef struct
{
  PSTR(     txt, 255 );
} _QTXT, * _QTXTPTR;


/* ----------------------------------------------------------------------- *
 *
 *  MSGINFO.BBS
 *
 * ----------------------------------------------------------------------- */

typedef struct
{
  word      lowmsg;
  word      highmsg;
  word      totalactive;
  word      activemsgs [200];
} _QINFO, * _QINFOPTR;


/* ----------------------------------------------------------------------- *
 *
 *  MSGTOIDX.BBS
 *
 * ----------------------------------------------------------------------- */

typedef struct 
{
  PSTR(     whoto, 35 );
} _QTOIDX, * _QTOIDXPTR;


/* ----------------------------------------------------------------------- *
 *
 *  USERS.BBS
 *
 * ----------------------------------------------------------------------- */

typedef struct
{
  PSTR(     name, 35 );
  PSTR(     city, 25 );
  PSTR(     pwd, 15 );
  PSTR(     dataphone, 12 );
  PSTR(     homephone, 12 );
  PSTR(     lasttime, 5 );
  PSTR(     lastdate, 8 );
  byte      attrib;
  byte      flags [4];
  int       credit;
  int       pending;
  int       timesposted;
  word      highmsgread;
  int       seclvl;
  int       times;
  int       ups;
  int       downs;
  int       upk;
  int       downk;
  int       todayk;
  int       elapsed;
  int       len;
  byte      extraspace [8];
} _QUSERS, * _QUSERSPTR;


#endif

/* End of file RASYS.H */
